.. _developer-api-reference:

Developer API reference
=======================

.. warning::

   The APIs documented here are not stable and may change from one version to
   another. This is meant to be used by developers, both of ``papis`` itself and
   any external plugins.

``papis.bibtex``
----------------

.. automodule:: papis.bibtex
    :members:

``papis.citations``
-------------------

.. automodule:: papis.citations
    :members:

``papis.cli``
-------------

.. automodule:: papis.cli
    :members:

``papis.commands``
------------------

.. automodule:: papis.commands
    :members:

``papis.config``
----------------

.. automodule:: papis.config
    :members:

``papis.docmatcher``
--------------------

.. automodule:: papis.docmatcher
    :members:

``papis.document``
------------------

.. automodule:: papis.document
    :members:

``papis.downloaders``
---------------------

.. automodule:: papis.downloaders
   :members:

``papis.exceptions``
--------------------

.. automodule:: papis.exceptions
   :members:

``papis.filetype``
------------------

.. automodule:: papis.filetype
   :members:

``papis.format``
----------------

.. automodule:: papis.format
    :members:

``papis.git``
-------------

.. automodule:: papis.git
    :members:

``papis.hooks``
---------------

.. automodule:: papis.hooks
   :members:

``papis.id``
------------

.. automodule:: papis.id
    :members:

``papis.importer``
------------------

.. automodule:: papis.importer
    :members:

``papis.library``
-----------------

.. automodule:: papis.library
    :members:

``papis.logging``
-----------------

.. automodule:: papis.logging
    :members:

``papis.notes``
---------------

.. automodule:: papis.notes
    :members:

``papis.paths``
---------------

.. automodule:: papis.paths
    :members:

``papis.pick``
--------------

.. automodule:: papis.pick
    :members:

``papis.plugin``
----------------

.. automodule:: papis.plugin
    :members:

``papis.sphinx_ext``
--------------------

.. automodule:: papis.sphinx_ext
    :members:

``papis.testing``
-----------------

.. automodule:: papis.testing
    :members:

``papis.utils``
---------------

.. automodule:: papis.utils
    :members:

``papis.yaml``
--------------

.. automodule:: papis.yaml
    :members:

``papis.commands.doctor``
-------------------------

.. automodule:: papis.commands.doctor
    :members:
